merlin.algorithms package
=========================

.. automodule:: merlin.algorithms
   :members:
   :undoc-members:
   :show-inheritance:

Submodules
----------

.. toctree::
   :maxdepth: 4

   merlin.algorithms.feed_forward
   merlin.algorithms.kernels
   merlin.algorithms.layer
   merlin.algorithms.loss
